[mlpack-git] master: Documents changes from 253c493 in gamma_distribution.hpp (8918550)

gitdub at mlpack.org gitdub at mlpack.org
Wed Aug 3 06:33:28 EDT 2016


Repository : https://github.com/mlpack/mlpack
On branch  : master
Link       : https://github.com/mlpack/mlpack/compare/b12e1517565652f62a551e1df41f2e51569bc9d9...e3ce1600893636f15be55d66c621398673b1faba

>---------------------------------------------------------------

commit 89185505d7b7513c10378a48e4ea9c53841e0b82
Author: Yannis Mentekidis <mentekid at gmail.com>
Date:   Wed Aug 3 11:33:28 2016 +0100

    Documents changes from 253c493 in gamma_distribution.hpp


>---------------------------------------------------------------

89185505d7b7513c10378a48e4ea9c53841e0b82
 src/mlpack/core/dists/gamma_distribution.hpp | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/mlpack/core/dists/gamma_distribution.hpp b/src/mlpack/core/dists/gamma_distribution.hpp
index b358298..2570289 100644
--- a/src/mlpack/core/dists/gamma_distribution.hpp
+++ b/src/mlpack/core/dists/gamma_distribution.hpp
@@ -79,19 +79,19 @@ class GammaDistribution
     void Train(const arma::mat& rdata, const double tol = 1e-8);
     
     /**
-     * This function trains (fits distribution parameters) to a 1-dimensional
-     * dataset with pre-computed statistics logMeanx, meanLogx, meanx.
+     * This function trains (fits distribution parameters) to a dataset with
+     * pre-computed statistics logMeanx, meanLogx, meanx for each dimension.
      *
      * @param logMeanx Is the dimension's logarithm of the mean (log(mean(x))).
      * @param meanLogx Is the dimension's mean of logarithms (mean(log(x))).
      * @param meanx Is the dimension's mean (mean(x)).
      * @param tol Convergence tolerance. This is *not* an absolute measure:
      *    It will stop the approximation once the *change* in the value is 
      *    smaller than tol.
      */
-    void Train(const arma::vec& logMeanx, 
-               const arma::vec& meanLogx, 
-               const arma::vec& meanx,
+    void Train(const arma::vec& logMeanxVec, 
+               const arma::vec& meanLogxVec, 
+               const arma::vec& meanxVec,
                const double tol = 1e-8);
 
     // Access to Gamma distribution parameters.
@@ -79,19 +79,19 @@ class GammaDistribution
      *
-     * @param logMeanx Is the dimension's logarithm of the mean (log(mean(x))).
-     * @param meanLogx Is the dimension's mean of logarithms (mean(log(x))).
-     * @param meanx Is the dimension's mean (mean(x)).
+     * @param logMeanxVec Is each dimension's logarithm of the mean (log(mean(x))).
+     * @param meanLogxVec Is each dimension's mean of logarithms (mean(log(x))).
+     * @param meanxVec Is each dimension's mean (mean(x)).
      * @param tol Convergence tolerance. This is *not* an absolute measure:
      *    It will stop the approximation once the *change* in the value is 




More information about the mlpack-git mailing list